# Docksible

## About

Docksible - Web apps in Docker containers via Ansible and super simple CLI. This is a work in progress. The following resources will likely prove useful.

* https://docs.ansible.com/ansible/latest/collections/community/docker/docker_compose_module.html
* https://docs.ansible.com/ansible/2.8/scenario_guides/guide_docker.html
